# -*- coding: utf-8; -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2023 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU General Public License as published by the Free Software
#  Foundation, either version 3 of the License, or (at your option) any later
#  version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
#  details.
#
#  You should have received a copy of the GNU General Public License along with
#  Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################
"""
CORE POS views
"""

from .master import CoreOfficeMasterView


def defaults(config, **kwargs):

    mod = lambda spec: kwargs.get(spec, spec)

    config.include(mod('tailbone_corepos.views.corepos.parameters'))
    config.include(mod('tailbone_corepos.views.corepos.tablesyncrules'))
    config.include(mod('tailbone_corepos.views.corepos.users'))
    config.include(mod('tailbone_corepos.views.corepos.groups'))
    config.include(mod('tailbone_corepos.views.corepos.stores'))
    config.include(mod('tailbone_corepos.views.corepos.departments'))
    config.include(mod('tailbone_corepos.views.corepos.subdepartments'))
    config.include(mod('tailbone_corepos.views.corepos.superdepartments'))
    config.include(mod('tailbone_corepos.views.corepos.vendors'))
    config.include(mod('tailbone_corepos.views.corepos.origins'))
    config.include(mod('tailbone_corepos.views.corepos.products'))
    config.include(mod('tailbone_corepos.views.corepos.likecodes'))
    config.include(mod('tailbone_corepos.views.corepos.scaleitems'))
    config.include(mod('tailbone_corepos.views.corepos.members'))
    config.include(mod('tailbone_corepos.views.corepos.customers'))
    config.include(mod('tailbone_corepos.views.corepos.employees'))
    config.include(mod('tailbone_corepos.views.corepos.coupons'))
    config.include(mod('tailbone_corepos.views.corepos.taxrates'))
    config.include(mod('tailbone_corepos.views.corepos.transactions'))
    config.include(mod('tailbone_corepos.views.corepos.batches'))
    config.include(mod('tailbone_corepos.views.corepos.purchaseorders'))


def includeme(config):
    defaults(config)



# -*- coding: utf-8; -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2022 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU General Public License as published by the Free Software
#  Foundation, either version 3 of the License, or (at your option) any later
#  version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
#  details.
#
#  You should have received a copy of the GNU General Public License along with
#  Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################
"""
CORE POS parameter views
"""

from corepos.db.office_op import model as corepos

from .master import CoreOfficeMasterView


class ParameterView(CoreOfficeMasterView):
    """
    Master view for parameters
    """
    model_class = corepos.Parameter
    model_title = "CORE-POS Parameter"
    url_prefix = '/core-pos/parameters'
    route_prefix = 'corepos.parameters'
    creatable = True
    editable = True
    deletable = True

    labels = {
        'store_id': "Store ID",
        'lane_id': "Lane ID",
    }

    def configure_grid(self, g):
        super(ParameterView, self).configure_grid(g)

        g.set_link('param_key')
        g.set_link('param_value')


def defaults(config, **kwargs):
    base = globals()

    ParameterView = kwargs.get('ParameterView', base['ParameterView'])
    ParameterView.defaults(config)


def includeme(config):
    defaults(config)



# -*- coding: utf-8; -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2022 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU General Public License as published by the Free Software
#  Foundation, either version 3 of the License, or (at your option) any later
#  version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
#  details.
#
#  You should have received a copy of the GNU General Public License along with
#  Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################
"""
Product Views
"""

from rattail_corepos.config import core_office_url

from webhelpers2.html import tags

from tailbone.views import ViewSupplement


class ProductViewSupplement(ViewSupplement):
    """
    Product view supplement for CORE integration
    """
    route_prefix = 'products'

    labels = {
        'corepos_id': "CORE-POS ID",
    }

    def get_grid_query(self, query):
        model = self.model
        return query.outerjoin(model.CoreProduct)

    def configure_grid(self, g):
        model = self.model
        g.set_filter('corepos_id', model.CoreProduct.corepos_id)

    def configure_form(self, f):
        if not self.master.creating:
            f.append('corepos_id')

    # def objectify(self, form, data=None):
    #     if data is None:
    #         data = form.validated
    #     product = super(ProductView, self).objectify(form, data)
    #     return self.corepos_objectify(product)

    # def corepos_objectify(self, product):
    #     # remove the corepos extension record outright, if we just lost the ID
    #     if product._corepos and not product.corepos_id:
    #         self.Session.delete(product._corepos)
    #         self.Session.flush()
    #     return product

    def get_version_child_classes(self):
        model = self.model
        return [model.CoreProduct]

    def get_panel_fields_main(self, product):
        return ['corepos_id']

    def get_xref_buttons(self, product):
        url = core_office_url(self.rattail_config)
        if url:
            url = '{}/item/ItemEditorPage.php?searchupc={}'.format(
                url, product.item_id)
            return [{'url': url, 'text': "View in CORE Office"}]

    def get_xref_links(self, product):
        if product.corepos_id:
            url = self.request.route_url('corepos.products.view',
                                         id=product.corepos_id)
            return [tags.link_to("View CORE-POS Product", url)]


def includeme(config):
    ProductViewSupplement.defaults(config)



# -*- coding: utf-8; -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2022 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU General Public License as published by the Free Software
#  Foundation, either version 3 of the License, or (at your option) any later
#  version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
#  details.
#
#  You should have received a copy of the GNU General Public License along with
#  Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################
"""
Vendor views
"""

from rattail_corepos.config import core_office_url

from tailbone.views import ViewSupplement


class VendorViewSupplement(ViewSupplement):
    """
    Vendor view supplement for CORE integration
    """
    route_prefix = 'vendors'

    labels = {
        'corepos_id': "CORE-POS ID",
    }

    def get_grid_query(self, query):
        model = self.model
        return query.outerjoin(model.CoreVendor)

    def configure_grid(self, g):
        model = self.model
        g.set_filter('corepos_id', model.CoreVendor.corepos_id)

    def configure_form(self, f):
        f.append('corepos_id')

    def get_version_child_classes(self):
        model = self.model
        return [model.CoreVendor]

    def get_xref_buttons(self, vendor):
        url = core_office_url(self.rattail_config)
        if url:
            url = '{}/item/vendors/VendorIndexPage.php?vid={}'.format(
                url, vendor.corepos_id)
            return [{'url': url, 'text': "View in CORE Office"}]


def includeme(config):
    VendorViewSupplement.defaults(config)
